;;;example code using template light curves.

;in this example, I use the code to generate a fake light-curve, add
;   noise to it, then demonstrate various ways of fitting the light curve.


n=20 ;points in each band
period_try=15.36  ;days




;load up the templates
restore, 'short_period_struc.sav'
short_struc=ceph_struc
restore, 'long_period_struc.sav'
long_struc=ceph_struc

plotsym, 0, /fill


t=[findgen(n),findgen(n),findgen(n)]+.5 ;generate dates for the LC



p0=[5.d0,6, 7, period_try, 2., n,2.*n ] ;parameters for the LC.  This LC will have an
                                ;average m_i=5, m_v=6, m_b=7,
                                ;period=set at top of file
                                ;days, phase shift=2 days, n means
                                ;that n is where the V-band data
                                ;starts and 2*n is where the B-band starts

if p0(3) lt 10 then ceph_struc=short_struc else ceph_struc=long_struc
;use the right template

print, 'Generating a template light curve'
light_curves=gen_lc(t, p0, struc=ceph_struc, pcoef=pcoef) ;generate a
                                ;model light curve


mplot, t, light_curves, psym=2, xtitle='Date (days)', ytitle='mi,mv,mb', $
title='Starting Light Curve' ;plot up the curve


print, 'type .c to continue with the example'
stop


print, 'Add noise to the LC and then find the best fitting template'
;add 0.05 mags of Gaussian noise to the LCs
seed=6  ;for repeatability
noise_level=.05
noise=randomn(seed,n*3)*noise_level
light_curves=light_curves+noise


;now try fitting the light curve and plot up the fit:

fit_params=template_fit( t(0:n-1), light_curves(0:n-1), $
                   light_curves(0:n-1)*0+noise_level, t(n:2*n-1), $
                   light_curves(n:2*n-1), $
                   light_curves(n:2*n-1)*0+noise_level, $
                   t(2*n:n*3-1), light_curves(2*n:3*n-1), $
                   light_curves(2*n:3*n-1)*0+noise_level, $
                   short_struc=short_struc, long_struc=long_struc, $
                   norm_err=norm_err, red_chi=red_chi, yfit=yfit)
;OK, that's a messy call. to break down each term
; t(0:9) :  dates for the I-band data
; light_curves(0:9) :  the I-band magnitudes
; light_curves(0:9)*0+noise_level : RMS uncertainty in each I-band
;                                   magnitude
; t(10:19) : dates for the V-band data
; light_curves(10:19) : the V-band magnitudes
;light_curves(10:19)*0+noise_level : V magnitude errors
;t(20:29) : dates for the B-band data
;light_curves(20:29):  the B-band magnitudes
;short_struc=ceph_struc : When fitting a period shorter than 10 days,
;                       use this structure
;long_struc=ceph_struc : When fitting a period longer than 10 days,
;                      use this structure.  
;norm_err=norm_err : return the normalized uncertainties of the fit
;                  parameters
; red_chi=red_chi : return the reduced chi^2 value
;yfit=yfit :  return the fitted curve






print, 'input paramenters:  '
print, '      mi                 mv       mb         Period     phase        10      20'
print, p0
print, 'fitted parameters:'
print, fit_params
print, 'returned errors:'
print, norm_err
print, 'reduced-chi^2 of the fit = ', red_chi

print, 'Hooray, the fitted parameters match the input and chi-squared is close to unity'


print, 'type .c to continue with the example'
stop

print, 'Make a pretty smooth curve to show how well the fit did'



x=(t mod fit_params(3))
mplot, x, light_curves, /nodata, xtitle='Phase',ytitle='magnitudes', $
title='light curve with smooth best fit.' 
oploterror, x, light_curves, light_curves*0+.05,psym=8

x=findgen(1001)/1000.*fit_params(3)
x=[x,x,x]

;here's an easy way to plot the two filters at the same time
oplot_split, (x mod fit_params(3)), gen_lc(x,[fit_params[0:4] $
              ,1001,2002],struc=ceph_struc),1001, 2002

 

print, 'type .c to continue with the example'
stop

 print, 'now to do the same fit, but leave the LC shape parameters as free variables'

fit_params=template_fit( t(0:n-1), light_curves(0:n-1), $
                   light_curves(0:n-1)*0+noise_level, t(n:2*n-1), $
                   light_curves(n:2*n-1), $
                   light_curves(n:2*n-1)*0+noise_level, $
                   t(2*n:n*3-1), light_curves(2*n:3*n-1), $
                   light_curves(2*n:3*n-1)*0+noise_level, $
                   short_struc=short_struc, long_struc=long_struc, $
                   norm_err=norm_err, red_chi=red_chi, yfit=yfit, ns=4)



;same as before, but now ns=4 leaves all 4 shape parameters free
print, 'input paramenters:  '
print, '      mi                 mv       mb         Period     phase        '+trim(n)+'      '+trim(2*n)
print, pcoef
print, 'fitted parameters:'
print, fit_params
print, 'returned errors:'
print, norm_err
print, 'reduced-chi^2 of the fit = ', red_chi




x=(t mod fit_params(3))
mplot, x, light_curves, /nodata, xtitle='Phase',ytitle='magnitudes' , $
title='light curve shape parameters left free'
oploterror, x, light_curves, light_curves*0+.05,psym=8

x=findgen(1001)/1000.*fit_params(3)
x=[x,x,x]


oplot_split, (x mod fit_params(3)), gen_lc(x,[fit_params[0:4] $
              ,1001,2002],struc=ceph_struc),1001, 2002


print, 'Hooray, the fit worked again.  Of course it took a lot longer trying to fit those extra shape parameters, but it still converged correctly.  Notice the reduced chi-squared hardly changed, so there is not much information in those extra shape parameters.'





end
